==> apache-sedona-1.3.0-incubating-src.tar.gz: apache-sedona-1.3.0-incubating-src/docs/setup/platform.md <==
Sedona binary releases are compiled by Java 1.8 and Scala 2.11/2.12 and tested in the following environments:

!!!warning
	Support of Spark 2.X and Scala 2.11 will be removed in Sedona 1.3.0+ although some parts of the source code might still be compatible. Sedona 1.3.0+ will release binary for both Scala 2.12 and 2.13.

=== "Sedona Scala/Java"
	
	|             | Spark 2.4 | Spark 3.0 | Spark 3.1 | Spark 3.2| Spark 3.3|
	|:-----------:| :---------:|:---------:|:---------:|:---------:|:---------:|
	| Scala 2.11  |  ✅  |  not tested  | not tested  | not tested  |not tested  |
	| Scala 2.12 | ✅  |  ✅  | ✅ | ✅ |✅ |
	| Scala 2.13 |  not tested  | not tested  | not tested  | ✅ but no release|✅ but no release|

=== "Sedona Python"
	
	|             | Spark 2.4 (Scala 2.11) | Spark 3.0 (Scala 2.12)|Spark 3.1 (Scala 2.12)| Spark 3.2 (Scala 2.12)| Spark 3.3 (Scala 2.12)|
	|:-----------:|:---------:|:---------:|:---------:|:---------:|:---------:|
	| Python 3.7  |  ✅  |  ✅  |  ✅  |  ✅  |  ✅  |
	| Python 3.8 | not tested  |  not tested  |not tested  |not tested  |  ✅  |
	| Python 3.9 | not tested  |  not tested  |not tested  |not tested  |  ✅  |
	| Python 3.10 | not tested  |  not tested  |not tested  |not tested  |  ✅  |

=== "Sedona R"
	
	|             | Spark 2.4 | Spark 3.0 | Spark 3.1 | Spark 3.2 | Spark 3.3 | 
	|:-----------:| :---------:|:---------:|:---------:|:---------:|:---------:|
	| Scala 2.11  |  ✅  |  not tested  | not tested  | not tested  | not tested  |
	| Scala 2.12 | not tested  |  ✅  | ✅ |  ✅ | ✅ | ✅ |

==> apache-sedona-1.3.1-incubating-src.tar.gz: apache-sedona-1.3.1-incubating-src/docs/setup/platform.md <==
Sedona binary releases are compiled by Java 1.8 and Scala 2.11/2.12 and tested in the following environments:

!!!warning
	Support of Spark 2.X and Scala 2.11 was removed in Sedona 1.3.0+ although some parts of the source code might still be compatible. Sedona 1.3.0+ release binary for both Scala 2.12 and 2.13.

=== "Sedona Scala/Java"
	
	|             | Spark 2.4 | Spark 3.0 | Spark 3.1 | Spark 3.2| Spark 3.3|
	|:-----------:| :---------:|:---------:|:---------:|:---------:|:---------:|
	| Scala 2.11  |  not tested  |  not tested  | not tested  | not tested  |not tested  |
	| Scala 2.12 | not tested  |  ✅  | ✅ | ✅ |✅ |
	| Scala 2.13 |  not tested  | not tested  | not tested  | not tested|✅ |

=== "Sedona Python"
	
	|             | Spark 2.4 (Scala 2.11) | Spark 3.0 (Scala 2.12)|Spark 3.1 (Scala 2.12)| Spark 3.2 (Scala 2.12)| Spark 3.3 (Scala 2.12)|
	|:-----------:|:---------:|:---------:|:---------:|:---------:|:---------:|
	| Python 3.7  |  not tested  |  ✅  |  ✅  |  ✅  |  ✅  |
	| Python 3.8 | not tested  |  not tested  |not tested  |not tested  |  ✅  |
	| Python 3.9 | not tested  |  not tested  |not tested  |not tested  |  ✅  |
	| Python 3.10 | not tested  |  not tested  |not tested  |not tested  |  ✅  |

=== "Sedona R"
	
	|             | Spark 2.4 | Spark 3.0 | Spark 3.1 | Spark 3.2 | Spark 3.3 | 
	|:-----------:| :---------:|:---------:|:---------:|:---------:|:---------:|
	| Scala 2.11  |  not tested  |  not tested  | not tested  | not tested  | not tested  |
	| Scala 2.12 | not tested  |  ✅  | ✅ |  ✅ | ✅ | ✅ |
